@@ -1,4 +1,6 @@
 import string
+import uuid
+from typing import Literal
 
 from auto_labeling_pipeline.models import RequestModelFactory
 from django.contrib.auth.models import User
@@ -38,6 +40,9 @@ class Project(PolymorphicModel):
     def get_annotation_class(self):
         raise NotImplementedError()
 
+    def is_task_of(self, task: Literal['text', 'image', 'speech']):
+        raise NotImplementedError()
+
     def __str__(self):
         return self.name
 
@@ -47,33 +52,50 @@ class TextClassificationProject(Project):
     def get_annotation_class(self):
         return Category
 
+    def is_task_of(self, task: Literal['text', 'image', 'speech']):
+        return task == 'text'
+
 
 class SequenceLabelingProject(Project):
+    allow_overlapping = models.BooleanField(default=False)
+    grapheme_mode = models.BooleanField(default=False)
 
     def get_annotation_class(self):
         return Span
 
+    def is_task_of(self, task: Literal['text', 'image', 'speech']):
+        return task == 'text'
+
 
 class Seq2seqProject(Project):
 
     def get_annotation_class(self):
         return TextLabel
 
+    def is_task_of(self, task: Literal['text', 'image', 'speech']):
+        return task == 'text'
+
 
 class Speech2textProject(Project):
 
     def get_annotation_class(self):
         return TextLabel
 
+    def is_task_of(self, task: Literal['text', 'image', 'speech']):
+        return task == 'speech'
+
 
 class ImageClassificationProject(Project):
 
     def get_annotation_class(self):
         return Category
 
+    def is_task_of(self, task: Literal['text', 'image', 'speech']):
+        return task == 'image'
+
 
 class Label(models.Model):
-    text = models.CharField(max_length=100)
+    text = models.CharField(max_length=100, db_index=True)
     prefix_key = models.CharField(
         max_length=10,
         blank=True,
@@ -99,7 +121,7 @@ class Label(models.Model):
     )
     background_color = models.CharField(max_length=7, default='#209cee')
     text_color = models.CharField(max_length=7, default='#ffffff')
-    created_at = models.DateTimeField(auto_now_add=True)
+    created_at = models.DateTimeField(auto_now_add=True, db_index=True)
     updated_at = models.DateTimeField(auto_now=True)
 
     def __str__(self):
@@ -124,11 +146,13 @@ class Label(models.Model):
         unique_together = (
             ('project', 'text'),
         )
+        ordering = ['created_at']
 
 
 class Example(models.Model):
+    id = models.UUIDField(primary_key=True, default=uuid.uuid4, editable=False, db_index=True)
     meta = models.JSONField(default=dict)
-    filename = models.FileField(default='.')
+    filename = models.FileField(default='.', max_length=1024)
     project = models.ForeignKey(
         to=Project,
         on_delete=models.CASCADE,
@@ -141,13 +165,37 @@ class Example(models.Model):
         blank=True
     )
     text = models.TextField(null=True, blank=True)
-    created_at = models.DateTimeField(auto_now_add=True)
+    created_at = models.DateTimeField(auto_now_add=True, db_index=True)
     updated_at = models.DateTimeField(auto_now=True)
 
     @property
     def comment_count(self):
         return Comment.objects.filter(example=self.id).count()
 
+    class Meta:
+        ordering = ['created_at']
+
+
+class ExampleState(models.Model):
+    example = models.ForeignKey(
+        to=Example,
+        on_delete=models.CASCADE,
+        related_name='states'
+    )
+    confirmed_by = models.ForeignKey(
+        to=User,
+        on_delete=models.CASCADE
+    )
+    confirmed_at = models.DateTimeField(auto_now=True)
+
+    class Meta:
+        unique_together = (('example', 'confirmed_by'),)
+
+    @property
+    def confirmed_user_role(self):
+        role_mapping = RoleMapping.objects.get(user=self.confirmed_by, project=self.example.project)
+        return role_mapping.role
+
 
 class Comment(models.Model):
     text = models.TextField()
@@ -161,7 +209,7 @@ class Comment(models.Model):
         on_delete=models.CASCADE,
         null=True
     )
-    created_at = models.DateTimeField(auto_now_add=True)
+    created_at = models.DateTimeField(auto_now_add=True, db_index=True)
     updated_at = models.DateTimeField(auto_now=True)
 
     @property
@@ -169,7 +217,7 @@ class Comment(models.Model):
         return self.user.username
 
     class Meta:
-        ordering = ('-created_at', )
+        ordering = ['created_at']
 
 
 class Tag(models.Model):
@@ -304,7 +352,7 @@ class AutoLabelingConfig(models.Model):
     model_name = models.CharField(max_length=100)
     model_attrs = models.JSONField(default=dict)
     template = models.TextField(default='')
-    label_mapping = models.JSONField(default=dict)
+    label_mapping = models.JSONField(default=dict, blank=True)
     project = models.ForeignKey(
         to=Project,
         on_delete=models.CASCADE,
@@ -327,3 +375,30 @@ class AutoLabelingConfig(models.Model):
         except Exception:
             message = 'The attributes does not match the model.'
             raise ValidationError(message)
+
+
+class RelationTypes(models.Model):
+    color = models.TextField()
+    name = models.TextField()
+    project = models.ForeignKey(Project, related_name='relation_types', on_delete=models.CASCADE)
+
+    def __str__(self):
+        return self.name
+
+    class Meta:
+        unique_together = ('color', 'name')
+
+
+class AnnotationRelations(models.Model):
+    annotation_id_1 = models.IntegerField()
+    annotation_id_2 = models.IntegerField()
+    type = models.ForeignKey(RelationTypes, related_name='annotation_relations', on_delete=models.CASCADE)
+    timestamp = models.DateTimeField()
+    user = models.ForeignKey(User, related_name='annotation_relations', on_delete=models.CASCADE)
+    project = models.ForeignKey(Project, related_name='annotation_relations', on_delete=models.CASCADE)
+
+    def __str__(self):
+        return self.__dict__.__str__()
+
+    class Meta:
+        unique_together = ('annotation_id_1', 'annotation_id_2', 'type', 'project')
