@@ -1,7 +1,8 @@
-import datetime
 import itertools
+import uuid
 
 from celery import shared_task
+from celery.utils.log import get_task_logger
 from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.shortcuts import get_object_or_404
@@ -14,6 +15,8 @@ from .views.upload.factory import (get_data_class, get_dataset_class,
                                    get_label_class)
 from .views.upload.utils import append_field
 
+logger = get_task_logger(__name__)
+
 
 class Buffer:
 
@@ -58,14 +61,14 @@ class DataFactory:
         self.label_class.objects.bulk_create(labels)
 
     def create_data(self, examples, project):
+        uuids = sorted(uuid.uuid4() for _ in range(len(examples)))
         dataset = [
-            self.data_class(project=project, **example.data)
-            for example in examples
+            self.data_class(id=uid, project=project, **example.data)
+            for uid, example in zip(uuids, examples)
         ]
-        now = datetime.datetime.now()
-        self.data_class.objects.bulk_create(dataset)
-        ids = self.data_class.objects.filter(created_at__gte=now)
-        return list(ids)
+        data = self.data_class.objects.bulk_create(dataset)
+        data.sort(key=lambda example: example.id)
+        return data
 
     def create_annotation(self, examples, ids, user, project):
         mapping = {label.text: label.id for label in project.labels.all()}
@@ -120,6 +123,7 @@ def injest_data(user_id, project_id, filenames, format: str, **kwargs):
             factory.create(buffer.data, user, project)
             buffer.clear()
     if not buffer.is_empty():
+        logger.debug(f'BUFFER LEN {len(buffer)}')
         factory.create(buffer.data, user, project)
         buffer.clear()
 
